@@ -51,7 +51,7 @@ printfeed(FILE *fp, const char *feedname)
 
 		printutf8pad(stdout, fields[FieldItemFullname], 25, ' ');
 		fputs("  ", stdout);
-		printescape(fields[FieldText]);
+		fputs(fields[FieldText], stdout);
 		putchar('\n');
 	}
 }
