@@ -106,43 +106,3 @@ printutf8pad(FILE *fp, const char *s, size_t len, int pad)
 	for (; col < len; ++col)
 		putc(pad, fp);
 }
-
-void
-printescape(const char *s)
-{
-	int r;
-	const char *e;
-
-	/* strip leading and trailing white-space */
-	for (; *s && isspace((unsigned char)*s); s++)
-		;
-	for (e = s + strlen(s); e > s && isspace((unsigned char)*(e - 1)); e--)
-		;
-
-	for (r = 0; *s && s < e; s++) {
-		if (iscntrl((unsigned char)*s) || isspace((unsigned char)*s)) {
-			r = 1;
-			continue;
-		}
-		if (r) {
-			r = 0;
-			putchar(' ');
-		}
-		putchar(*s);
-	}
-}
-
-int
-parsetime(const char *s, time_t *t, char *buf, size_t bufsiz)
-{
-	struct tm *tm;
-
-	if (strtotime(s, t))
-		return -1;
-	if (!(tm = localtime(t)))
-		return -1;
-	if (!strftime(buf, bufsiz, "%Y-%m-%d %H:%M", tm))
-		return -1;
-
-	return 0;
-}
