@@ -30,8 +30,6 @@ enum {
 };
 
 size_t  parseline(char *, char *[FieldLast]);
-int     parsetime(const char *, time_t *, char *, size_t);
-void    printescape(const char *);
 void    printutf8pad(FILE *, const char *, size_t, int);
 int     strtotime(const char *, time_t *);
 void    xmlencode(const char *, FILE *);
